@@ -343,7 +343,7 @@ class RPCBase(abc.ABC):
             from decoding and deserializing should be raised as
             :class:`~.RPCError`.
         """
-        _log.debug('%s: [%s] Calling: %s, %s', self.label, self.status, args, kwargs)
+        # _log.debug('%s: [%s] Calling: %s, %s', self.label, self.status, args, kwargs)
         if self.status is not _utils.ConnectionStatus.connected:
             _log.debug('%s: Auto-connecting', self.label)
             await self.connect()
