@@ -86,7 +86,12 @@ def cached_property(fget):
     return _cached_property(fget)
 
 
-class URL:
+class _URLMeta(type):
+    def __init__(cls, name, bases, attrs):
+        # Convert default URL to instance of `cls`
+        cls.default = cls(cls.default)
+
+class URL(metaclass=_URLMeta):
     """
     URL of an RPC interface
 
@@ -102,17 +107,19 @@ class URL:
     :raise ValueError: if `url` is invalid
     """
 
-    @staticmethod
-    def _dict_from_string(string):
+    _parts = (
+        'scheme',
+        'username',
+        'password',
+        'host',
+        'port',
+        'path',
+    )
+
+    @classmethod
+    def _dict_from_string(cls, string):
         string = str(string).strip()
-        parts = {
-            'scheme': None,
-            'username': None,
-            'password': None,
-            'host': None,
-            'port': None,
-            'path': None,
-        }
+        parts = {k: None for k in cls._parts}
 
         # Scheme
         scheme_regex = re.compile(r'^(.*?)://')
@@ -156,15 +163,39 @@ class URL:
 
         return parts
 
+    @classmethod
+    def _dict_from_any(cls, thing):
+        if thing is None:
+            return cls._dict_from_string('')
+
+        elif isinstance(thing, str):
+            return cls._dict_from_string(thing)
+
+        # URL class is not in the global namespace yet, so we can't do
+        # `isinstance(thing, URL)`. Instead, we do duck-typing and rely on
+        # `with_auth` method providing what we expect.
+        elif hasattr(thing, 'with_auth'):
+            return cls._dict_from_string(thing.with_auth)
+
+        else:
+            raise TypeError(f'Unsupported type: {type(thing).__name__}: {thing!r}')
+
     default = ''
     """URL to use when ``url`` and ``default`` arguments are both falsy"""
 
-    def __init__(self, url, default=None, on_change=None):
-        # Don't trigger any changes until we finished parsing the initial value
+    def __new__(cls, url=None, default=None, on_change=None):
+        # Get instance
+        self = super().__new__(cls)
+
+        # Don't trigger any changes until we finished initialization
         self._on_change = None
 
-        default_url = self._dict_from_string(default or self.default)
-        custom_url = self._dict_from_string(url)
+        default_url = cls._dict_from_any(default or cls.default)
+        if url:
+            custom_url = cls._dict_from_any(url)
+        else:
+            custom_url = default_url
+
         for name in ('scheme', 'username', 'password', 'host', 'port', 'path'):
             if custom_url[name]:
                 setattr(self, name, custom_url[name])
@@ -174,9 +205,11 @@ class URL:
                 except _errors.ValueError:
                     setattr(self, name, None)
 
-        # Initial parsing is complete - enable on_change callback
+        # Initialization is complete - enable on_change callback
         self._on_change = on_change
 
+        return self
+
     @property
     def scheme(self):
         """Scheme (e.g. ``"http"`` or ``"file"``)"""
