@@ -1,6 +1,7 @@
 import asyncio
 import collections
 import re
+import sys
 import weakref
 from unittest.mock import Mock, PropertyMock, call
 
@@ -586,8 +587,14 @@ def test_http_headers():
     for i in range(3):
         assert rpc._http_headers is rpc._http_headers
 
-    # Python 3.10 added the attribute name to the error message
-    with pytest.raises(AttributeError, match=r"^can't set attribute(?: '_http_headers'|)$"):
+    if sys.version_info >= (3, 11):
+        exp_msg = "property '_http_headers' of 'MockRPC' object has no setter"
+    elif sys.version_info >= (3, 10):
+        exp_msg = "can't set attribute '_http_headers'"
+    else:
+        exp_msg = "can't set attribute"
+
+    with pytest.raises(AttributeError, match=rf'^{re.escape(exp_msg)}$'):
         rpc._http_headers = 'asdf'
 
 
