@@ -21,5 +21,7 @@ class AsyncMock(Mock):
 
 
 def make_url_parts(url):
-    return {name: getattr(url, name)
-            for name in ('scheme', 'host', 'port', 'path', 'username', 'password')}
+    return {
+        name: getattr(url, name)
+        for name in ('scheme', 'host', 'port', 'path', 'username', 'password')
+    }
