@@ -90,8 +90,8 @@ def test_cached_property():
 @pytest.mark.parametrize(
     argnames='url, exp_parts_or_exception',
     argvalues=(
-        ('',
-         {'scheme': None, 'host': None, 'port': None, 'path': None, 'username': None, 'password': None}),
+        (None, {'scheme': None, 'host': None, 'port': None, 'path': None, 'username': None, 'password': None}),
+        ('', {'scheme': None, 'host': None, 'port': None, 'path': None, 'username': None, 'password': None}),
 
         # No scheme without path
         ('localhost',
@@ -166,31 +166,58 @@ def test_cached_property():
     ids=lambda v: str(v),
 )
 def test_URL_parsing(url, exp_parts_or_exception):
+    def make_url(url):
+        if url is not None:
+            return _utils.URL(url)
+        else:
+            return _utils.URL()
+
     if isinstance(exp_parts_or_exception, Exception):
         exception = exp_parts_or_exception
         with pytest.raises(type(exception), match=rf'^{re.escape(str(exception))}$'):
-            _utils.URL(url)
+            make_url(url)
     else:
-        url = _utils.URL(url)
+        url = make_url(url)
         exp_parts = exp_parts_or_exception
         parts = make_url_parts(url)
         assert parts == exp_parts
 
 default_url_testcases = (
-    ('foo:bar@localhost:123/some/path', 'socks://x:y@defaulthost:999/default/path',
-     {'scheme': 'socks', 'host': 'localhost', 'port': '123', 'path': '/some/path', 'username': 'foo', 'password': 'bar'}),
-    ('http://:bar@localhost:123/some/path', 'socks://x:y@defaulthost:999/default/path',
-     {'scheme': 'http', 'host': 'localhost', 'port': '123', 'path': '/some/path', 'username': 'x', 'password': 'bar'}),
-    ('http://foo:@localhost:123/some/path', 'socks://x:y@defaulthost:999/default/path',
-     {'scheme': 'http', 'host': 'localhost', 'port': '123', 'path': '/some/path', 'username': 'foo', 'password': 'y'}),
-    ('http://foo:bar@localhost/some/path', 'socks://x:y@defaulthost:999/default/path',
-     {'scheme': 'http', 'host': 'localhost', 'port': '999', 'path': '/some/path', 'username': 'foo', 'password': 'bar'}),
-    ('http://foo:bar@localhost:123/', 'socks://x:y@defaulthost:999/default/path',
-     {'scheme': 'http', 'host': 'localhost', 'port': '123', 'path': '/', 'username': 'foo', 'password': 'bar'}),
-    ('http://foo:bar@localhost:123', 'socks://x:y@defaulthost:999/default/path',
-     {'scheme': 'http', 'host': 'localhost', 'port': '123', 'path': '/default/path', 'username': 'foo', 'password': 'bar'}),
-    ('http://foo:bar@localhost:asdf', None,
-     _errors.ValueError('Invalid port')),
+    (
+        'foo:bar@localhost:123/some/path',
+        'socks://x:y@defaulthost:999/default/path',
+        {'scheme': 'socks', 'host': 'localhost', 'port': '123', 'path': '/some/path', 'username': 'foo', 'password': 'bar'},
+    ),
+    (
+        'http://:bar@localhost:123/some/path',
+        'socks://x:y@defaulthost:999/default/path',
+        {'scheme': 'http', 'host': 'localhost', 'port': '123', 'path': '/some/path', 'username': 'x', 'password': 'bar'},
+    ),
+    (
+        'http://foo:@localhost:123/some/path',
+        'socks://x:y@defaulthost:999/default/path',
+        {'scheme': 'http', 'host': 'localhost', 'port': '123', 'path': '/some/path', 'username': 'foo', 'password': 'y'},
+    ),
+    (
+        'http://foo:bar@localhost/some/path',
+        'socks://x:y@defaulthost:999/default/path',
+        {'scheme': 'http', 'host': 'localhost', 'port': '999', 'path': '/some/path', 'username': 'foo', 'password': 'bar'},
+    ),
+    (
+        'http://foo:bar@localhost:123/',
+        'socks://x:y@defaulthost:999/default/path',
+        {'scheme': 'http', 'host': 'localhost', 'port': '123', 'path': '/', 'username': 'foo', 'password': 'bar'},
+    ),
+    (
+        'http://foo:bar@localhost:123',
+        'socks://x:y@defaulthost:999/default/path',
+        {'scheme': 'http', 'host': 'localhost', 'port': '123', 'path': '/default/path', 'username': 'foo', 'password': 'bar'},
+    ),
+    (
+        'http://foo:bar@localhost:asdf',
+        None,
+        _errors.ValueError('Invalid port'),
+    ),
 )
 
 @pytest.mark.parametrize('url, default_url, exp_parts_or_exception', default_url_testcases)
@@ -198,6 +225,8 @@ def test_URL_default_url_attribute(url, default_url, exp_parts_or_exception):
     class MyURL(_utils.URL):
         default = default_url
 
+    assert isinstance(MyURL.default, MyURL)
+
     if isinstance(exp_parts_or_exception, Exception):
         exception = exp_parts_or_exception
         with pytest.raises(type(exception), match=rf'^{re.escape(str(exception))}$'):
